@@ -40,7 +40,7 @@
  */
 
 .pragma library
-.import QtQuick 2.0 as Quick
+.import QtQuick 2.6 as Quick
 .import GCompris 1.0 as GCompris
 
 var levels = [
@@ -154,7 +154,8 @@ function initLevel() {
     currentFuel = (maxFuel == -1 ? 1 : maxFuel); // -1 means unlimited fuel
 
     // reset everything:
-    items.rocket.explosion.hide();
+    items.explosion.hide();
+    items.rocket.show();
     // place rocket randomly:
     var max = items.background.width - items.accelerometer.width - items.landing.width - items.rocket.width;
     var min = 20;
@@ -301,7 +302,8 @@ function finishLevel(success)
     if (success)
         items.bonus.good("lion");
     else {
-        items.rocket.explosion.show();
+        items.explosion.show();
+        items.rocket.hide();
         items.bonus.bad("lion");
     }
 }
