@@ -33,6 +33,7 @@
 #include "ApplicationInfo.h"
 #include "ActivityInfoTree.h"
 #include "File.h"
+#include "Directory.h"
 #include "DownloadManager.h"
 
 bool loadAndroidTranslation(QTranslator &translator, const QString &locale)
@@ -71,8 +72,8 @@ QString loadTranslation(QSettings &config, QTranslator &translator)
     if(locale == GC_DEFAULT_LOCALE)
         locale = QString(QLocale::system().name() + ".UTF-8");
 
-    if(locale == "C.UTF-8")
-        locale = "en_US.UTF-8";
+    if(locale == "C.UTF-8" || locale == "en_US.UTF-8")
+        return "en_US";
 
     // Load translation
     // Remove .UTF8
@@ -108,6 +109,10 @@ int main(int argc, char *argv[])
     // Disable it because we already support HDPI display natively
     qunsetenv("QT_DEVICE_PIXEL_RATIO");
 
+#if defined(Q_OS_WIN)
+    QApplication::setAttribute(Qt::AA_UseSoftwareOpenGL);
+#endif
+
     QApplication app(argc, argv);
     app.setOrganizationName("KDE");
     app.setApplicationName(GCOMPRIS_APPLICATION_NAME);
@@ -168,10 +173,11 @@ int main(int argc, char *argv[])
 
 
     ApplicationInfo::init();
-	ActivityInfoTree::init();
+    ActivityInfoTree::init();
     ApplicationSettings::init();
-	File::init();
-	DownloadManager::init();
+    File::init();
+    Directory::init();
+    DownloadManager::init();
 
     // Tell media players to stop playing, it's GCompris time
     ApplicationInfo::getInstance()->requestAudioFocus();
